﻿using System.Text;

namespace TestProject;

/// <summary>
/// 메인 페이지
/// </summary>
public partial class MainPage : ContentPage
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
    ////////////////////////////////////////////////////////////////////////////////////////// Public

    #region 생성자 - MainPage()

    /// <summary>
    /// 생성자
    /// </summary>
    public MainPage()
    {
        InitializeComponent();

        this.label.Text = GetMessage(Connectivity.Current.NetworkAccess, Connectivity.Current.ConnectionProfiles);

        Connectivity.ConnectivityChanged += connectivity_ConnectivityChanged;
    }

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Private
    //////////////////////////////////////////////////////////////////////////////// Event

    #region 연결 변경시 처리하기 - connectivity_ConnectivityChanged(sender, e)

    /// <summary>
    /// 연결 변경시 처리하기
    /// </summary>
    /// <param name="sender">이벤트 발생자</param>
    /// <param name="e">이벤트 인자</param>
    private void connectivity_ConnectivityChanged(object sender, ConnectivityChangedEventArgs e)
    {
        this.label.Text = GetMessage(e.NetworkAccess, e.ConnectionProfiles);
    }

    #endregion

    //////////////////////////////////////////////////////////////////////////////// Function

    #region 메시지 구하기 - GetMessage(networkAccess, profileEnumerable)

    /// <summary>
    /// 메시지 구하기
    /// </summary>
    /// <param name="networkAccess">네트워크 액세스</param>
    /// <param name="profileEnumerable">프로필 열거 가능형</param>
    /// <returns>메시지</returns>
    private string GetMessage(NetworkAccess networkAccess, IEnumerable<ConnectionProfile> profileEnumerable)
    {
        StringBuilder stringBuilder = new StringBuilder();

        stringBuilder.AppendLine($"네트워크 액세스 : {networkAccess}");
        stringBuilder.AppendLine( "연결 프로필");

        foreach(ConnectionProfile profile in profileEnumerable)
        {
            stringBuilder.AppendLine($"    {profile}");
        }

        return stringBuilder.ToString();
    }

    #endregion
}